aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CST116-BlankConsole/CST116-BlankConsole.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/CST116-BlankConsole/CST116-BlankConsole.cpp b/CST116-BlankConsole/CST116-BlankConsole.cpp
index f52b208..77a5279 100644
--- a/CST116-BlankConsole/CST116-BlankConsole.cpp
+++ b/CST116-BlankConsole/CST116-BlankConsole.cpp
@@ -1,11 +1,14 @@
// CST116-BlankConsole.cpp : This file contains the 'main' function. Program execution begins and ends there.
//
#include <iostream>
+using std::endl
+using std::cout
int main()
{
- std::cout << "Hello World!\n";
+ cout << "Hello World!"endl;
+ cout << "My name is Levi Davis and my GitHub user is levidavis04" endl;
}
// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
@@ -1,11 +1,14 @@
-// CST116-BlankConsole.cpp : This file contains the 'main' function. Program execution begins and ends there.
+// CST116-BlankConsole.cpp : CST Lab0 Levi Davis This file contains the 'main' function. Program execution begins and ends there.
//
#include <iostream>